/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.drawables;

import java.util.ArrayList;
import java.util.Iterator;

import net.moioli.chart.DrawableI;
import net.moioli.chart.GraphicsI;
import net.moioli.chart.Scale;

/**
 * Represents a DefaultChart's legend.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
class Legend implements DrawableI {
    /** Elements in this Legend. */
    private ArrayList elementi = new ArrayList();

    /**
     * Default constructor (empty Legend)
     */
    public Legend() {
        super();
    }

    /**
     * Standard constructor.
     * 
     * @param e
     *            an array with the Legend's elements
     */
    public Legend(LegendElement e[]) {
        this();
        for (int i = 0; i < e.length; i++) {
            this.elementi.add(e[i]);
        }
    }

    /**
     * Implements DrawableI drawing this object.
     * 
     * @param g
     *            the surface where this object will be drawn
     * @param s
     *            the DefaultChart's Scale object
     * @param c
     *            the color to be used for drawing
     */
    public void drawMe(GraphicsI g, Scale s, Object c) {
        int x = s.getScreenMaxX();
        int y = 0;
        g.drawString("Legend:", x - g.getStringWidth("Legend:"), y);
        y += g.getStringHeight();
        Iterator i = this.elementi.iterator();
        while (i.hasNext()) {
            LegendElement e = (LegendElement) i.next();
            e.setXY(x, y);
            e.drawMe(g, s, c);
            y += e.getHeight(g);
        }
    }

    /**
     * Since the Legend will be drawn regardless of the scale, always return
     * NaN.
     * 
     * @param minX
     *            the minimum x value represented in this DefaultChart
     * @param maxX
     *            the maximum x value represented in this DefaultChart
     * @return NaN
     */
    public double maxY(double minX, double maxX) {
        return Double.NaN;
    }

    /**
     * Since the Legend will be drawn regardless of the scale, always return
     * NaN.
     * 
     * @param minX
     *            the minimum x value represented in this DefaultChart
     * @param maxX
     *            the maximum x value represented in this DefaultChart
     * @return NaN
     */
    public double minY(double minX, double maxX) {
        return Double.NaN;
    }
}